{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "it",
  "direction": "ltr",
  "clipboard.copy": "Copia",
  "clipboard.copied": "Copiato",
  "edit.link.title": "Modifica",
  "footer.previous": "Precedente",
  "footer.next": "Prossimo",
  "footer.title": "Piede",
  "header.title": "Intestazione",
  "meta.comments": "Commenti",
  "meta.source": "Sorgente",
  "nav.title": "Navigazione",
  "search.config.lang": "it",
  "search.placeholder": "Cerca",
  "search.share": "Condividi",
  "search.reset": "Cancella",
  "search.result.initializer": "Inizializza la ricerca",
  "search.result.placeholder": "Scrivi per iniziare a cercare",
  "search.result.none": "Nessun documento trovato",
  "search.result.one": "1 documento trovato",
  "search.result.other": "# documenti trovati",
  "search.result.more.one": "1 altro in questa pagina",
  "search.result.more.other": "# altri in questa pagina",
  "search.result.term.missing": "Non presente",
  "search.title": "Cerca",
  "select.language.title": "Seleziona la lingua",
  "select.version.title": "Seleziona la versione",
  "skip.link.title": "Vai al contenuto",
  "source.link.title": "Apri repository",
  "source.file.date.updated": "Ultimo aggiornamento",
  "source.file.date.created": "Creata",
  "tabs.title": "Tabs",
  "toc.title": "Indice",
  "top.title": "Torna su"
}[key] }}{% endmacro %}
